aboutsummaryrefslogtreecommitdiffstats
path: root/examples/charts/chartthemes
diff options
context:
space:
mode:
Diffstat (limited to 'examples/charts/chartthemes')
-rw-r--r--examples/charts/chartthemes/README.md2
-rw-r--r--examples/charts/chartthemes/main.py10
-rw-r--r--examples/charts/chartthemes/ui_themewidget.py6
3 files changed, 9 insertions, 9 deletions
diff --git a/examples/charts/chartthemes/README.md b/examples/charts/chartthemes/README.md
index e11fa93c5..806e391d2 100644
--- a/examples/charts/chartthemes/README.md
+++ b/examples/charts/chartthemes/README.md
@@ -3,7 +3,7 @@
To generated the file `ui_themewidget.py`, the following
command need to be executed:
-`pyside2-uic themewidget.ui > ui_themewidget.py`
+`pyside6-uic themewidget.ui > ui_themewidget.py`
Also, if you modify the UI file, then you would need
to run the previous command again.
diff --git a/examples/charts/chartthemes/ui_themewidget.py b/examples/charts/chartthemes/ui_themewidget.py
index bf6703963..d2fdf55bc 100644
--- a/examples/charts/chartthemes/ui_themewidget.py
+++ b/examples/charts/chartthemes/ui_themewidget.py
@@ -8,10 +8,10 @@
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################
-from PySide2.QtCore import (QCoreApplication, QMetaObject, QObject, QPoint,
+from PySide6.QtCore import (QCoreApplication, QMetaObject, QObject, QPoint,
QRect, QSize, QUrl, Qt)
-from PySide2.QtGui import (QColor, QFont, QIcon, QPixmap)
-from PySide2.QtWidgets import *
+from PySide6.QtGui import (QColor, QFont, QIcon, QPixmap)
+from PySide6.QtWidgets import *
class Ui_ThemeWidgetForm(object):
def setupUi(self, ThemeWidgetForm):
diff --git a/examples/charts/chartthemes/main.py b/examples/charts/chartthemes/main.py
index e18e92cf2..423806490 100644
--- a/examples/charts/chartthemes/main.py
+++ b/examples/charts/chartthemes/main.py
@@ -38,14 +38,14 @@
##
#############################################################################
"""PySide2 port of the Chart Themes example from Qt v5.x"""
import sys
-from PySide2.QtCore import QPointF, Qt
-from PySide2.QtGui import QColor, QPainter, QPalette
-from PySide2.QtWidgets import (QApplication, QMainWindow, QSizePolicy,
+from PySide6.QtCore import QPointF, Qt
+from PySide6.QtGui import QColor, QPainter, QPalette
+from PySide6.QtWidgets import (QApplication, QMainWindow, QSizePolicy,
QWidget)
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCharts import QtCharts
from ui_themewidget import Ui_ThemeWidgetForm as ui
@@ -38,14 +38,14 @@
##
#############################################################################
-"""PySide2 port of the Chart Themes example from Qt v5.x"""
+"""PySide6 port of the Chart Themes example from Qt v5.x"""
import sys